/**************************************************************************
*  Copyright (c) 2013-2015 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  27.12.2013  mifi  First Version
**************************************************************************/
#define __STAT_C__

/*=======================================================================*/
/*  Include                                                              */
/*=======================================================================*/
#include "nut_io.h"

#include <errno.h>
#include <sys/device.h>
#include <sys/stat.h>
#include <io.h>

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/
/*************************************************************************/
/*  _fstat                                                               */
/*                                                                       */
/*  Get information about the file.                                      */
/*                                                                       */
/*  In    : fd, s                                                        */
/*  Out   : none                                                         */
/*  Return: 0 on success, -1 otherwise.                                  */
/*************************************************************************/
int _fstat (int fd, struct _stat *s)
{
   int          rc = -1;
   NUTFILE   *fp;
   NUTDEVICE *dev;
    
   if ((unsigned int)fd >= FOPEN_MAX)
   {
      errno = EBADF;
      return -1;
   }

   if ((fp = __fds[fd]) == NULL) 
   {
      errno = EBADF;
      return -1;
   }

   dev = fp->nf_dev;
   if(dev->dev_stat)
   {
      rc = (*dev->dev_stat)(fp, s);
   }
   
   return(rc);   
} /* _fstat */

/*** EOF ***/
