/**************************************************************************
*  Copyright (c) 2018 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  18.04.2018  mifi  First Version.
**************************************************************************/
#define __DEV_TERMINAL_C__

/*=======================================================================*/
/*  Includes                                                             */
/*=======================================================================*/
#include <stdint.h>
#include "tal.h"
#include "terminal.h"

#include "sys/device.h"
#include "dev/dev_terminal.h"

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all global Data                                        */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

static NUTFILE TermFile;

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

static int devTermInit (NUTDEVICE * dev)
{
   dev->dev_dcb = &TermFile;

   return(0);
}

static int devTermIOCtl (NUTDEVICE * dev, int req, void *conf)
{
   (void)dev;
   (void)req;
   (void)conf;
   
   return(-1);
}

static int devTermWrite (NUTFILE * fp, const void *buffer, int len)
{
   (void)fp;
   
   len = term_write((uint8_t*)buffer, len);
   
   return(len);
}

static NUTFILE *devTermOpen (NUTDEVICE * dev, const char *name, int mode, int acc)
{
   NUTFILE *fp = (NUTFILE *)dev->dev_dcb;
   
   (void)name;
   (void)mode;
   (void)acc;

   fp->nf_dev = dev;
   fp->nf_fcb = NULL;

   return(fp);
}

static int devTermClose (NUTFILE * fp)
{
   (void)fp;
   
   return(0);
}

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/


/*!
 * Terminal device information structure.
 */
NUTDEVICE devTerminal = 
{
   0,             /* Pointer to next device, dev_next. */
   {'t', 'e', 'r', 'm', '0', 0, 0, 0, 0}, /* Unique device name, dev_name. */
   IFTYP_CHAR,    /* Type of device, dev_type. */
   0,             /* Base address, dev_base. */
   0,             /* First interrupt number, dev_irq. */
   0,             /* Interface control block, dev_icb. */
   0,             /* Driver control block, dev_dcb. */
   devTermInit,   /* Driver initialization routine, dev_init. */
   devTermIOCtl,  /* Driver specific control function, dev_ioctl. */
   0,             /* dev_read. */
   devTermWrite,  /* dev_write. */
   devTermOpen,   /* dev_open. */
   devTermClose,  /* dev_close. */
   0,             /* dev_size. */
   0,             /* dev_select, optional, not yet implemented */
   0              /* dev_stat */
};


/*** EOF ***/
