/**************************************************************************
*  Copyright (c) 2013-2014 by Michael Fischer.
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  31.12.2013  mifi  First Version
**************************************************************************/
#define __EVENT_C__

/*=======================================================================*/
/*  Include                                                              */
/*=======================================================================*/
#include <stdlib.h>
#include <string.h>
#include "tal.h"
#include "sys/event.h"

/*=======================================================================*/
/*  All Structures and Common Constants                                  */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Data                                         */
/*=======================================================================*/

/*=======================================================================*/
/*  Definition of all local Procedures                                   */
/*=======================================================================*/

/*=======================================================================*/
/*  All code exported                                                    */
/*=======================================================================*/

/*************************************************************************/
/*  NutEventCreate                                                       */
/*                                                                       */
/*  Create a eventflag.                                                  */
/*                                                                       */
/*  In    : event                                                        */
/*  Out   : none                                                         */
/*  Return: 0 = OK / -1 = Error                                          */
/*************************************************************************/
int NutEventCreate (NUTEVENT *event)
{
   OSSemaCreate(event, 0, 1);
   
   return(0);
} /* NutEventCreate */

/*************************************************************************/
/*  NutEventDelete                                                       */
/*                                                                       */
/*  Delete a eventflag.                                                  */
/*                                                                       */
/*  In    : event                                                        */
/*  Out   : none                                                         */
/*  Return: 0 = OK / -1 = Error                                          */
/*************************************************************************/
int NutEventDelete (NUTEVENT *event)
{
   OSSemaDelete(event);
   
   return(0);
} /* NutEventDelete */

/*************************************************************************/
/*  NutEventPost                                                         */
/*                                                                       */
/*  Set a eventflag.                                                     */
/*                                                                       */
/*  In    : event                                                        */
/*  Out   : none                                                         */
/*  Return: 0 = OK / -1 = Error                                          */
/*************************************************************************/
int NutEventPost (NUTEVENT *event)
{
   OSSemaSignal(event);
   
   return(0);
} /* NutEventPost */

/*************************************************************************/
/*  NutEventPostFromIrq                                                  */
/*                                                                       */
/*  Set a eventflag from interrupt                                       */
/*                                                                       */
/*  In    : event                                                        */
/*  Out   : none                                                         */
/*  Return: 0 = OK / -1 = Error                                          */
/*************************************************************************/
int NutEventPostFromIrq (NUTEVENT *event)
{
   OSSemaSignalFromInt(event);
   
   return(0);
} /* NutEventPostFromIrq */

int NutEventPostAsync (NUTEVENT *event)
{
   OSSemaSignalNoSched(event);
   
   return(0);
} /* NutEventPostAsync */

int NutEventBroadcast (NUTEVENT *event)
{
   OSSemaBroadcast(event);
   
   return(0);
} /* NutEventBroadcast */

int NutEventBroadcastAsync (NUTEVENT *event)
{
   OSSemaBroadcastAsync(event);
   
   return(0);
} /* NutEventBroadcastAsync */

/*************************************************************************/
/*  NutEventWait                                                         */
/*                                                                       */
/*  Wait for an event with timeout, 0 = infinite.                        */
/*                                                                       */
/*  In    : event                                                        */
/*  Out   : none                                                         */
/*  Return: 0 = OK / -1 = Error                                          */
/*************************************************************************/
int NutEventWait (NUTEVENT *event, uint32_t timeout_ms)
{
   int rc;
   
   if (0 == timeout_ms)
   {
      timeout_ms = OS_WAIT_INFINITE;  
   }
   
   rc = OSSemaWait(event, timeout_ms);
   if (OS_RC_TIMEOUT == rc)
   {
      rc = -1;
   }
   
   return(rc);
} /* NutEventWait */

int NutEventThreadIsWaitung (NUTEVENT *event)
{
   int rc = 1; /* Thread is waiting */

   if (0 == event->Fifo.pOut) 
   {
      /* Queue is empty, no thread waiting */
      rc = 0;
   }
   
   return(rc);
} /* NutEventThreadIsWaitung */

/*** EOF ***/
