/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2017 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  30.01.2017  mifi  First Version, tested with an Embedded Artists 
*                    LPC1788 Developer's Kit.
*  04.02.2017  mifi  Tested with an Embedded Artist
*                    LPC2468 Developer's Kit.
**************************************************************************/
#if !defined(__ENET_24XX_17XX_40XX_H__)
#define __ENET_24XX_17XX_40XX_H__

/**************************************************************************
*  Includes
**************************************************************************/
#include <stdint.h>

/**************************************************************************
*  Global Definitions
**************************************************************************/

#if defined(USE_BOARD_EA1788) || defined(USE_BOARD_EA4088) || defined(USE_BOARD_QSB4088) || defined(USE_BOARD_BF4088) || defined(USE_BOARD_BFCAN)
#include "enet_17xx_40xx.h"
#define ENET_NUM_BUFF_RXDESCS    10    /* Number of RX Descriptors */
#define ENET_NUM_BUFF_TXDESCS    10    /* Number of TX Descriptors */
#define ENET_ETHERNET_BASE       0x20084000
#endif
 
#if defined(USE_BOARD_EA2468) 
#include "enet_24xx.h"
#define ENET_NUM_BUFF_RXDESCS    4     /* Number of RX Descriptors */
#define ENET_NUM_BUFF_TXDESCS    3     /* Number of TX Descriptors */
#define ENET_ETHERNET_BASE    0xFFE00000
#endif


/*
 * Ethernet MAC register
 */
#define ENET_MAC1    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x000))
#define ENET_MAC2    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x004))
#define ENET_IPGT    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x008))
#define ENET_IPGR    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x00C))
#define ENET_CLRT    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x010))
#define ENET_MAXF    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x014))
#define ENET_SUPP    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x018))
#define ENET_TEST    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x01C))
#define ENET_MCFG    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x020))
#define ENET_MCMD    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x024))
#define ENET_MADR    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x028))
#define ENET_MWTD    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x02C))
#define ENET_MRDD    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x030))
#define ENET_MIND    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x034))
#define ENET_SA0     (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x040))
#define ENET_SA1     (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x044))
#define ENET_SA2     (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x048))

/*
 * Ethernet Control register
 */
#define ENET_COMMAND                (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x100))
#define ENET_STATUS                 (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x104))

#define ENET_RX_DESCRIPTOR          (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x108))
#define ENET_RX_STATUS              (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x10C))
#define ENET_RX_DESCRIPTOR_NUMBER   (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x110))
#define ENET_RX_PRODUCE_INDEX       (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x114))
#define ENET_RX_CONSUME_INDEX       (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x118))

#define ENET_TX_DESCRIPTOR          (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x11C))
#define ENET_TX_STATUS              (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x120))
#define ENET_TX_DESCRIPTOR_NUMBER   (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x124))
#define ENET_TX_PRODUCE_INDEX       (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x128))
#define ENET_TX_CONSUME_INDEX       (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x12C))

#define ENET_TSV0                   (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x158))
#define ENET_TSV1                   (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x15C))
#define ENET_RSV                    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x160))
#define ENET_FLOW_CONTROL_COUNTER   (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x170))
#define ENET_FLOW_CONTROL_STATUS    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x174))

/*
 * Ethernet RX filter register
 */
#define ENET_RX_FILTER_CTRL         (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x200))
#define ENET_RX_FILTER_WOL_STATUS   (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x204))
#define ENET_RX_FILTER_WOL_CLEAR    (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x208))
#define ENET_HASHFILTERL            (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x210))
#define ENET_HASHFILTERH            (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0x214))

/*
 * Ethernet Module control register
 */
#define ENET_INT_STATUS             (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0xFE0))
#define ENET_INT_ENABLE             (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0xFE4))
#define ENET_INT_CLEAR              (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0xFE8))
#define ENET_INT_SET                (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0xFEC))
#define ENET_POWER_DOWN             (*(volatile unsigned *)(ENET_ETHERNET_BASE + 0xFF4))


/*
 * Interrupt Status/Enable/Clear/Set Register bit definitions
 */ 
#define ENET_INT_RX              ENET_INT_RXDONE
#define ENET_INT_RX_ERROR        ENET_INT_RXERROR
#define ENET_INT_RX_OVERRUN      ENET_INT_RXOVERRUN

#define ENET_INT_TX              ENET_INT_TXDONE
#define ENET_INT_TX_ERROR        ENET_INT_TXERROR
#define ENET_INT_TX_UNDERRUN     ENET_INT_TXUNDERRUN

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

void     enet_Init (uint8_t UseRMII);
void     enet_Start (void);

uint32_t enet_GetIRQStatus (void);  
void     enet_ClearIRQStatus(uint32_t dStatus);

void     enet_MACAddressConfig (uint8_t *pBuffer);
void     enet_UpdateLink (uint8_t bLinkStatus);

int      enet_MulticastAddFilter (uint32_t dAddress);
int      enet_MulticastDelFilter (uint32_t dAddress);

uint16_t enet_PHYRegRead (uint16_t wAddress, uint16_t wReg);
void     enet_PHYRegWrite (uint16_t wAddress, uint16_t wReg, uint16_t wValue);

uint8_t *enet_RxFrameGet (uint16_t *pSize);
void     enet_RxFrameReady (void);
void     enet_RxOverrun (void);

uint8_t *enet_TxFrameGet (void);
void     enet_TxFrameSend(uint16_t wSize);
void     enet_TxUnderrun (void);

#endif /* !__ENET_24XX_17XX_40XX_H__ */

/*** EOF ***/
